pitchtools.MelodicChromaticIntervalClass
========================================

.. autoclass:: abjad.tools.pitchtools.MelodicChromaticIntervalClass
   :members:
   :undoc-members:
   :show-inheritance:
